@@ -1,6 +1,6 @@
 import networkx as nx
 
-from features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
+from ...features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
 
 
 class PageRankCalculator(NodeFeatureCalculator):
@@ -22,5 +22,5 @@ feature_entry = {
 }
 
 if __name__ == "__main__":
-    from measure_tests.specific_feature_test import test_specific_feature
+    from ...measure_tests.specific_feature_test import test_specific_feature
     test_specific_feature(PageRankCalculator, is_max_connected=True)
